@@ -41,18 +41,6 @@ class ExperimentStepData(object):
         return {colname: NumpyFieldData(self.group, df[colname])
                 for colname in columns}
 
-    def concat_add_all_scalars(self, npf_data, npf_to_df=lambda npf_arr: pd.DataFrame(npf_arr)):
-        scalars_subdf = self.scalars_df.loc[npf_data.refs.index]
-        lst_to_concat = []
-
-        for scalars_row, npf_arr in zip(scalars_subdf.itertuples(index=False), npf_data):
-            inner_df = npf_to_df(npf_arr)
-            for i, (colname, val) in enumerate(zip(self.scalars_df.columns, scalars_row)):
-                inner_df.insert(i, colname, val)
-            lst_to_concat.append(inner_df)
-
-        return pd.concat(lst_to_concat)
-
     def __str__(self):
         return 'ExperimentStepData <step #%d "%s">' % (self.ind, self.name)
 
