@@ -10,7 +10,7 @@ class ExperimentsData(object):
     @property
     def experiments(self):
         groups = [group
-                  for group in ed.h5file.values()
+                  for group in self.h5file.values()
                   if group.attrs.get('_is_experiment', False)]
         experiments = map(ExperimentData, groups)
         return sorted(experiments, key=lambda e: e.time)
